"""
Copyright (C) 2020-2022 Murilo Marques Marinho (www.murilomarinho.info)
This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public
License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later
version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
You should have received a copy of the GNU General Public License along with this program. If not,
see <https://www.gnu.org/licenses/>.
"""
# TODO add the default values here as well
shared_memory_map = {
    "n_servos": 0,
    "n_potentiometers": 1,
    "n_digital_inputs": 2,
    "is_open": 3,
    "port": 4,
    "port_connect_signal": 5,
    "shutdown_flag": 6
}
